@@ -4,10 +4,17 @@
 #include <io.h>
 #include <math.h>
 
-/* The forall() macro cannot be nested.
- * We apply explicit flattening to a self-scheduling parallel loop
- * to exploit 2D parallelism.
+#define REQUIRED_SPACE 4096    /* overall #words of shared memory */
+sh static int myheap;
+sh static int mycurr;
+
+/* The forall()/gforall() macro cannot be nested.
+ * Denote further levels of parallelism by sforall(),
+ * a sequentialized variant of the gforall macro:
  */
+#define sforall(i,lb,ub,p) for(i=(lb); i<(ub); i++)  /*ignore p*/
+
+double one = 1.0;    /* workaround; local constants crash */
 
 typedef double ** syst;
 typedef double *  eq;
@@ -23,9 +30,9 @@ sync syst build_system( sh int *pn )
   sh syst s;
   sh int p = groupsize();
   n = 3;    /*example values*/
-  seq s = (syst) shmalloc( n * sizeof( eq ));
+  farm if ($==0) s = (syst) shmalloc( n * sizeof( eq ));
   farm
-    forall (i, 0, n, p)
+    gforall (i, 0, n, p)
       s[i] = (eq) shmalloc( (n+1) * sizeof( double )); 
   s[0][0] = 2.0;   s[0][1] =  -1.0;   s[0][2] = 3.0;  s[0][3]=6.0;
   s[1][0] =-1.0;   s[1][1] =   3.0;   s[1][2] =-5.0;  s[1][3]=4.0;
@@ -63,39 +70,25 @@ sync void eliminate( sh syst a, sh int n )
    * of the modified system tableau.
    */
  sh int r;
- pr int i, j, ij;
- sh int p = 0;
- sh int nextij;
- sh double *rowfactor = (double *)shalloc( n * sizeof(double));
- $ = mpadd( &p, 1 );   // renumber
+ pr int i, j;
+ sh int p = groupsize();
  
  for (r=0; r<n; r++) {  /* do n elimination steps */ 
-    sh double factor = 1.0 / a[r][r];
-    nextij = 0;
-
-    seq printf("Stage %d factor %lf p=%d\n", r, factor, p);
+    sh double factor = one / a[r][r];
+    farm if ($==0) printf("Stage %d factor %lf p=%d\n", r, factor, p);
     /* my pivot element is a[r][r] because a is diag. dom. */
-
     /* normalize equation r: */
-    farm
-      for ( j=r+$; j<n+1; j+=p ) 
-        a[r][j] = a[r][j] * factor;
-
-    farm
-      for ( i=$; i<n; i+=p ) 
-        rowfactor[i] = a[i][r];   // copying avoids data dependencies
-
-    farm {
-     for( ij = mpadd(&nextij,1); ij < n*(n+1); ij = mpadd(&nextij,1) )  {
-      i = ij / (n+1);  // row index of element to be updated
-      if (i!=r) {
-        /* update row i: */
-        j = ij % (n+1);  // column index of element to be updated
-        if (j<r) continue;
-        a[i][j] = a[i][j] - a[r][j] * rowfactor[i]; 
-      }
-     }
+    gforall ( j, r, n+1, p ) {
+       a[r][j] = factor * a[r][j];
     }
+    sforall ( i, 0, n, 1 )   /* update row i */
+      if (i!=r) {
+        pr double myfactor = a[i][r];  /*scaling factor*/
+        farm
+          gforall ( j, r, n+1, p ) {  /* update column j: */
+            a[i][j] = a[i][j] - a[r][j] * myfactor;
+          }
+      }
     farm if ($==0) print_system( a, n, n );
  }  /* for r */
  return;
@@ -105,7 +98,7 @@ sync void eliminate( sh syst a, sh int n )
 sh syst s;     /* system tableau */
 sh int n;      /* n eq's in m var's */
 
-void main( void )
+async main()
 {
   pr int starttime, stoptime;
   start {
