@@ -4,9 +4,9 @@
 #include <io.h>
 
 
-void main(void) 
+main() 
 {
- pr unsigned int t = getct();
+ pr int t = getct();
  if (__PROC_NR__==0)
    if (__STARTED_PROCS__ >=4)
      pprintf("Using 4 of the %d processors\n\n", __STARTED_PROCS__); 
