@@ -10,11 +10,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#define DEBUG 0
-
-#ifdef FTELL_EXPLICIT
-sh int _filepos[_NFILE];
-#endif
 
 /*-----------output routines----------------------------------------*/
 
@@ -57,16 +52,6 @@ void prI( int number, int leading ) {
 
 static char __hexdigit[] = "0123456789abcdef";
 
-void itohexs( int n, char *buf, int width )
-{
-  int i, z;
-  for ( i=width-1; i>=0; i--) {
-     z = n & 15;
-     buf[i] = __hexdigit[z];
-     n = n>>4;
-  }
-}
-
 void prX( int x ) {
  int e;
  int pos;
@@ -97,6 +82,8 @@ void prF( float xx ) {
 }
  
  
+extern pr int __PROC_NR__;
+
 void prstat( void ) {
  prI(__PROC_NR__, 0);
  write(1,": $=",4); prI($,0);
@@ -104,28 +91,6 @@ void prstat( void ) {
 }
 
 
-void printAccStat( void )         /*990119*/
-{
-  extern int _barrWaitTime;  /*990504*/
-
-  write(1,"AccStat for P", 13);
-  prI(__PROC_NR__,0); 
-  write(1,": ",2);
-  prI(_myshldgcnt,0); write(1," of ",4);
-  prI(_shldgcnt,0); write(1," sh-loads,\t",11);
-  prI(_myshstgcnt,0); write(1," of ",4);
-  prI(_shstgcnt,0); write(1," sh-stores,\n                ",28);
-  prI(_mympaddcnt,0); write(1," of ",4);
-  prI(_mpaddcnt,0); write(1," mp/syncadds,\t",14);
-  prI(_mympmaxcnt,0); write(1," of ",4);
-  prI(_mpmaxcnt,0); write(1," mp/syncmaxs,\n                ",30);
-  prI(_mympandcnt,0); write(1," of ",4);
-  prI(_mpandcnt,0); write(1," mp/syncands,\t",14);
-  prI(_mymporcnt,0); write(1," of ",4);
-  prI(_mporcnt,0); write(1," mp/syncors\n",12);
-}
-
-
 
 /* ============ scanf()   CWK  ! THIS IS A HACK !   3.11.1995 ====== */
 
@@ -198,7 +163,6 @@ char stdin_linebuf[stdin_linebufsize];
 static int stdin_linecurrent = 0;
 char stdinbuffer[STDINBUFFERSIZE];  /* stack of unmygetchar'd chars*/
 
-
 int mygetchar( char *stdin_buffer )   /*only for STANDARD INPUT, stdin */
 {
    char x;
@@ -379,15 +343,9 @@ int _scanf(
 		  zeroin:
 		    p = ((char *) strchr((char *)digits,toupper(c)));
 		}
-#if DEBUG
-                printf("read n=%d, NEG=%d\n", n, neg);
-#endif
 	      savnum:
 		if (store) {
-		    p = ((char *) *(args));
-#if DEBUG
-                printf("store to %d\n", p);
-#endif
+		    p = ((char *) *args);
 		    if (neg == TRUE)
 			n = -n;
 		    if (lval)
@@ -399,7 +357,7 @@ int _scanf(
 		    ++cnt;
 		}
 		goto breakouterswitch;
-              }
+              }		
 #if FLOATS
 	      /*case 'e':	/* float */ /*case 'f': case 'g':*/
               if (hilf=='e'||hilf=='f'||hilf=='g') {
@@ -432,7 +390,7 @@ int _scanf(
 		    goto done;
 		if (store) {
 		    fx = (*fbuf == '\0') ? 0.0 : atof(fbuf);
-		    p = (char *) *(args);
+		    p = (char *) *args;
 		    if (lval)    *((double *) p) = fx;
 		    else         *((float *) p) = (float)fx;
 		    ++cnt;
@@ -443,7 +401,7 @@ int _scanf(
 	      /*case 'n':*/
               if (hilf=='n') {
 		if (store) {
-		  p = (char *) *(args);
+		  p = (char *) *args;
 		  *((int *) p) = cnt;
 		}
 		goto breakouterswitch;
@@ -500,7 +458,7 @@ int _scanf(
 		skip();
 	      strproc:
 		/* process string */
-		p = ((char *) *(args));
+		p = ((char *) *args);
 		
 		/* if the 1st char fails, match fails */
 		if (width) {
@@ -557,9 +515,6 @@ int _scanf(
 	
 	if (store) {
 	    args++; 
-#if DEBUG
-            printf("incr. args = %d\n", args);
-#endif
         }
 	if (!*++fmt)
 	    break; /*while*/
@@ -578,14 +533,14 @@ int sgetc( char *s )
 {
 	char c;
 
-	c = *((*(char **)s)++);
+	c = *(s++);
 	return((c == '\0') ? EOF : c);
 }
 
 int sungetc( int c, char *s )
 {
   if(c == EOF)   c = '\0';
-  return (*(--(*(char **)s)) = c);
+  return (*(--s) = c);
 }
 
 int sscanf( char *buf, const char *fmt, ... )
@@ -593,7 +548,7 @@ int sscanf( char *buf, const char *fmt, ... )
   va_list argp;
 
   va_start(argp, fmt);
-  return(_scanf((char *) &buf, sgetc, sungetc, (char *)fmt, (char **)argp+1)); /* &buf */
+  return(_scanf((char *) &buf, sgetc, sungetc, (char *)fmt, (char **)argp)); /* &buf */
 }
 
 int fscanf(FILE *fp, const char *fmt, ...)
@@ -602,10 +557,8 @@ int fscanf(FILE *fp, const char *fmt, ...)
 
 	va_start(argp, fmt);
 	return(_scanf((char *)fp, (int (*)(char *))fgetc,
-                      (int (*)(int,char *))ungetc, (char *)fmt,
+                      (int (*)(int,char *))ungetc, (char *)fmt, (char **)argp));
                     /* ^^^^^^ fool the C compiler. CWK */
-                      (char **)argp + 1));
-                               /*   ^^^ notw. aus unerfindlichem Grund 9708 */
 }
 
 int scanf(const char *fmt, ...)
@@ -701,7 +654,6 @@ FILE *fopen( const char *name, const char *mode )
  fp->buffer = __UNBUFALLOC__;
  fp->buffersize = __UNBUFSIZE__;
  fp->current = 0;  /* no character ungetc'd for new file */
- fp->lock = 0;  /* initially unlocked */
  __iob[fd] = fp;
  return fp;
 }
@@ -711,25 +663,16 @@ int fclose ( FILE *fp )
 {
  /* returns zero if closing was OK. */
  int errcode;
- if (! fp ) return 1;
+ assert( fp );
  errcode = close (fp->fd);
  if (!errcode) {
-    shfree( fp->buffer );
+    free( fp->buffer );
     __iob[fp->fd] = NULL;
-    FILEFREE( fp );
+    free( fp );
  }
  return errcode;
 }
  
-int fflush( FILE *fp )
-{
- assert( fp );
- if (fp->buffer) {
-    pprintf("fflush: buffered output not supported, sorry \n");   
-    return 1;
- }
- return 0;
-}
 
 int fputc ( int c, FILE *fp )
 {
@@ -754,7 +697,7 @@ int fgetc ( FILE *fp )
     int k = read( fp->fd, &c, 1 );
     if (k==0) { fp->flag |= _IOEOF; return EOF; }
  }
-#if DEBUG
+#if 0
  printf("fgetc: %c\n", c);
 #endif
  return c;
@@ -764,7 +707,7 @@ int fgetc ( FILE *fp )
 int ungetc( int x, FILE *fp )
 {
    assert(fp);
-#if DEBUG
+#if 0
    printf("ungetc %c\n", x);
 #endif
    if (x==EOF)  x = (int) '\0';
@@ -828,49 +771,3 @@ char *gets ( char *s )
  }
  return ps;
 }
-
-
-/* direct file access 970811 */
-
-int fseek( FILE *stream, long int offset, int whence )
-{
- int fd = stream->fd;
- int ret;
- 
- if ( fd > _NFILE ) return -1;   /*error: out of range*/
- if ( fd < 0 ) return -2;         /*error: out of range*/
-
- if (whence==SEEK_CUR) { /*first look at buffer */
-      offset = offset - stream->current;
-#ifdef FTELL_EXPLICIT
-      _filepos[fd] += offset;
-#endif
- }
- else if (whence == SEEK_SET) {
-    if (offset <0) return 2;  /*error*/
-#ifdef FTELL_EXPLICIT
-    _filepos[fd] = offset;
-#endif
-    stream->current = 0; /*clear buffer:*/
- } 
- else if (whence == SEEK_END) {
-    if (offset >0 && (stream->mode & O_RDONLY) ) return 3;  /*error*/
-    assert(0);     /* don't know how to find the filepos of EOF */
-    /* _filepos[fd] = ? */
- }
- else return 1;   /*error: whence out of range*/
-
- ret = lseek( fd, offset, whence );
- printf("lseek=%d: fd=%d offset=%d whence=%d\n", ret,fd, offset, whence);
- return ret;
-}
-
-
-long ftell( FILE *stream )
-{
- int fd = stream->fd;
- return lseek( fd, 0, SEEK_CUR );
-#ifdef FTELL_EXPLICIT
- return _filepos[fd]; 
-#endif
-}
