@@ -1,8 +1,5 @@
 /* adapted for Fork95 by CWK 950401 */
 
-/* Some of this material was taken from the GNU C library,
- * here is their copyleft remark:*/
-
 /* Copyright (C) 1991 Free Software Foundation, Inc.
 Material in this file was part of the GNU C Library.
 
@@ -43,8 +40,6 @@ extern void *memcpy( void *, const void *, size_t);
 extern int errno;
 
 
-#include "shmalloc.c"
-
 #if 0
 /* This stuff is not usable for FORK.    CWK */
 
@@ -231,11 +226,6 @@ extern struct exit_function *EXFUN(__new_exitfn, (NOARGS));
 /* Return the absolute value of I.  */
 
 
-int abs( int i )
-{
-  return(i < 0 ? -i : i);
-}
-
 long int labs (long int i)
 {
   return(i < 0 ? -i : i);
@@ -783,7 +773,7 @@ double strtod (const char *nptr, char **endptr)
 	goto overflow;
     }
 #endif
-  /*pprintf("%d\n", itento(-exponent));*/
+  pprintf("%d\n", itento(-exponent));
   if (exponent >0) dnum = (itof(num)) * (float)itento(exponent);
   if (exponent <0) dnum = (itof(num)) / (float)itento(-exponent);
   return dnum * itof(sign);
