@@ -6,7 +6,7 @@ extern async void pra( void );
 sh int a[4] = { 2, 1, 3, 1 };
 sh int shmemloc;
 
-void main( void ){
+main(){
   start if ($<4) { 
     farm pra();
     a[$] = mpadd( &shmemloc, a[$]); 
@@ -19,8 +19,7 @@ void main( void ){
   }
 }
 
-void pra( void ) 
-{
+void pra() {
  int i;
  for(i=0;i<8*$;i++); /*delay loop*/
  prIln( a[$]);
