@@ -198,8 +198,6 @@ struct symbol {      /* symbol structures: */
    long regparameters; /*CWK: Bitvektor, bei Fn.: Bit i=1->Parameter i passed by reg*/
    int parreg;  /*CWK: falls >0, gibt Nr. des Parameter-Registers an */
    int reg;   /*CWK, nimmt Registernummer fuer Debugger auf*/
-   int shframedepth;  /*CWK neu 970902*/
-   int nreturns;  /* 990525 */
 };
 
 
@@ -268,8 +266,6 @@ struct node {      /* dag nodes: */
        started,  /*CWK: extension for returning from FORK start*/
        synchron, /*CWK: extension indicating synchronous execution*/
        maybe_priv; /*CWK: extension replicating treenode's ->maybe_pr */
-   int shframedepth; /*970902*/
-   int resetshoffset; /*970903*/
 };
 
 #define islabel(p) ((p) && (p)->op == LABEL+V && (p)->syms[0])
@@ -398,7 +394,7 @@ struct tynode {      /* type nodes: */
 #endif
    long sharedparams;  /* i-tes Bit == 1, falls i-ter Parameter shared  CWK*/
    long regparams;     /* i-tes Bit == 1, falls i-ter Parameter in Reg. CWK*/
-   int synchronicity;  /* carrier fuer syncity von Fn-Pointer-Deklarat. CWK*/
+   /*int synchronicity;  /* carrier fuer syncity von Fn-Pointer-Deklarat. CWK*/
 };
 
 struct field {      /* struct/union fields: */
@@ -524,7 +520,6 @@ dclproto(extern int main,(int, char **));
 dclproto(extern Symbol mkstr,(char *));
 dclproto(extern Symbol mksymbol,(int, char *,Type));
 extern int Aflag;
-extern int Tflag; /* gen code for access statistics */
 extern int Pflag;
 extern int isFORKmodul;                                   /*CWK*/
 extern Symbol YYnull;
