@@ -177,16 +177,8 @@ void gencode(caller, callee) Symbol caller[], callee[]; {
    cp->prev = codelist;
    for (bp = 0, cp = &codehead; errcnt <= 0 && cp; cp = cp->next)
       switch (cp->kind) {
-      case Start: case Asm: case Switch: 
+      case Start: case Asm: case Switch: case Pcode:   /*CWK*/
          break;
-      case Pcode:   /*CWK*/
-         { extern int resetshoffset;
-          assert(cp->u.node);        /*970903*/
-          if (cp->u.node->resetshoffset) {
-             resetshoffset = 1;
-          }
-          break;
-         }
       case Defpoint: 
          src = cp->u.point.src;
          break;
@@ -268,7 +260,6 @@ static Node list(p) Node p; {
 Node listnodes(tp, tlab, flab) Tree tp; {
    Opcode op;
    Node p, l, r;
-   extern int shframedepth;  /*970902*/
 
    if (tp == 0)
       return 0;
@@ -302,14 +293,22 @@ Node listnodes(tp, tlab, flab) Tree tp; {
       return r;
    case COND: {
       Tree q;
+      int priv;     /* if 1 then generate group frames, like xxxifstmt CWK */
       assert(tlab == 0 && flab == 0);
       if (tp->u.sym)
          addlocal(tp->u.sym);
       trash(0);
+      priv = may_dep_on_pr_var( tp->kids[0] );       /* condition CWK */
+      priv = priv && isinsyncmode;  /* CWK */
+      if (priv) warning("maybe private `?'-condition may introduce a deadlock!\n");
+      /* falls priv==1, erzeuge Gruppenframes, uebersetze wie privates IF */
+      priv = 0;     /*einfuegen von Pcode in Ausdr. klappt nicht ! MIST!  CWK */
+      if (priv) splitSM();           /*CWK: Speicher aufteilen */
       listnodes(tp->kids[0], 0, flab = genlabel(2));
       trash(0);
       if (q = tp->kids[1]) {
          assert(q->op == RIGHT);
+         if (priv) nextcase(0);    /* CWK: then-Gruppe aufmachen */
          listnodes(q->kids[0], 0, 0);
          if (islabel(nodelist)) {
             equatelab(nodelist->syms[0], findlabel(flab + 1));
@@ -320,6 +319,7 @@ Node listnodes(tp, tlab, flab) Tree tp; {
       if (q && q->kids[1]) {
          list(jump(flab + 1));
          labelnode(flab);
+         if (priv) nextcase(1);     /* CWK: else-Gruppe aufmachen */
          listnodes(q->kids[1], 0, 0);
          if (islabel(nodelist)) {
             equatelab(nodelist->syms[0], findlabel(flab + 1));
@@ -332,6 +332,8 @@ Node listnodes(tp, tlab, flab) Tree tp; {
       if (tp->u.sym) {
          Tree t = idnode(tp->u.sym);
          tp->u.sym->ref = 0;   /* undo idnode's setting ref */
+         if (priv) lgrp_if();             /*CWK*/
+         if (priv) synchronize();        /*CWK*/
          p = listnodes(t, 0, 0);
       }
       break;
@@ -533,8 +535,6 @@ Node listnodes(tp, tlab, flab) Tree tp; {
       p = node(tp->op, l, r, 0);
       p->synchron = tp->synchron;      /*durchreichen CWK*/
       p->maybe_priv = tp->maybe_pr;    /*CWK*/
-      trash(0);   /*970708 to care about side effects*/
-      list(p);   /*970708 to care about side effects*/
       break;
    case RET:
    case SRET:  /*CWK*/
@@ -606,8 +606,6 @@ Node listnodes(tp, tlab, flab) Tree tp; {
       p = node(tp->op, 0, 0, tp->u.sym);
       p->synchron = tp->synchron;      /*durchreichen CWK*/
       p->maybe_priv = 0;    /*CWK*/
-      assert(shframedepth>=0);
-      p->shframedepth = shframedepth;   /*970902*/
       break;
    case ADDRSG: case ADDRSF:                /*CWK, vorlaeufig, nur kopiert */
       assert(tlab == 0 && flab == 0);
@@ -624,25 +622,15 @@ Node listnodes(tp, tlab, flab) Tree tp; {
       p->synchron = tp->synchron;      /*durchreichen CWK*/
       p->maybe_priv = 1;    /*CWK*/
       break;
-   case ENGRP: case ENLGRP: case NEXTCASE: 
    case ADR_PROZ_NUM: case ADR_GRP_NUM:
-   case SYNC: case SPLIT: case LGRPIF:
-   case EXGRP: case XPROC: case RETFLUSH:
-   case EXLGRP: case SIZE: case IBP: case FLUSHFRAMES:
-   case BEGSEQ: case ENDSEQ:
-   case SHSPACE: /*970902*/
-   case JBLOCKa: case JBLOCKc: case JBLOCKd:
-   case JBLOCKe: case JBLOCKf: case JBLOCKg: case JBLOCKh:
+   case SYNC:
+   case SPLIT: case NEXTCASE: case LGRPIF:
+   case ENGRP: case EXGRP: case XPROC: case RETFLUSH:
+   case ENLGRP: case EXLGRP: case SIZE: case IBP: case FLUSHFRAMES:
       p = newnode(tp->op, 0, 0, 0);
       p->synchron = tp->synchron;      /*durchreichen CWK*/
-      p->resetshoffset = 0; /*970903*/
-      if (op==ENGRP || op==SPROC /* nicht auskommentiert 970908*/
-          || op==JBLOCKf   /*990126*/
-          || op==ENLGRP || op==NEXTCASE) {
-          p->resetshoffset = 1;        /*970903*/
-      } 
       break;
-   case MKGRP: case SPROC: case ILOG2: case JBLOCKb:
+   case MKGRP: case SPROC: case ILOG2:
       assert(tlab == 0 && flab == 0);
       l = listnodes(tp->kids[0], 0, 0);
       p = node(tp->op, l, 0, 0);
@@ -656,6 +644,7 @@ Node listnodes(tp, tlab, flab) Tree tp; {
 /* jump - return tree for a jump to lab */
 Node jump(lab) {
    Symbol p = findlabel(lab);
+
    p->ref++;
    return newnode(JUMP+V, node(ADDRG+P, 0, 0, p), 0, 0);
 }
