@@ -2,8 +2,6 @@
 
 #include "c.h"
 int isinsyncmode = 0;   /* global flag to pass mode of syncness to function calls CWK*/
-int isinsideastartbody = 0; /* global flag to know whether a start occured*/
-static int SEQcounter = 0;  /*counts SEQ statements, used to generate labels*/
 
 #define SWITCHSIZE 512      /* initial size of switch arrays */
 
@@ -34,7 +32,6 @@ dclproto(static void xxxdostmt,(int, struct swtch *, int, int)); /*CWK*/
 dclproto(static int foldcond,(Tree, Tree));
 dclproto(static void forstmt,(int, struct swtch *, int, int));
 dclproto(static void xxxforstmt,(int, struct swtch *, int, int)); /*CWK*/
-dclproto(static void joinstmt,(int, struct swtch *, int, int)); /*990126*/
 dclproto(static void forkstmt,(int, struct swtch *, int, int, int, int));   /*CWK*/
 dclproto(static void startstmt,(int, struct swtch *, int));   /*CWK*/
 dclproto(static void ifstmt,(int, int, struct swtch *, int, int, int, int));
@@ -171,7 +168,6 @@ static void dostmt(lab, swp, lev, rframes) struct swtch *swp; {
 static void xxxdostmt(lab, swp, lev, rframes) struct swtch *swp; {
    Tree e;  /*CWK*/
    extern void enlgrp(int), size(), exlgrp(), synchronize();  /*CWK*/
-   extern int shframedepth; 
    int priv;   /*CWK*/
    /* CWK:  Da das statement zuerst geemitted wird, aber erst nach Parsen von
     * e bekannt ist, ob private Pcode-Befehle eingefuegt werden muessen,
@@ -208,7 +204,6 @@ static void xxxdostmt(lab, swp, lev, rframes) struct swtch *swp; {
    enlgrp( 2 );
    definelab(lab);
    size();
-   shframedepth++;
    statement(lab, swp, lev, 0, 0, rframes + 1);
    definelab(lab + 1);
    expect(WHILE);
@@ -218,7 +213,6 @@ static void xxxdostmt(lab, swp, lev, rframes) struct swtch *swp; {
    walk(e, lab, 0);
    if (findlabel(lab + 2)->ref)
       definelab(lab + 2);
-   shframedepth--;  // 990712 moved here
    exlgrp();
    synchronize();  /*CWK*/
 }
@@ -333,142 +327,6 @@ static void forstmt(lab, swp, lev, rframes) struct swtch *swp; {
       definelab(lab + 2);
 }
 
-static int joincounter = 0;  /* counts join statements in this source */
-
-/* joinstmt - join ( [expr1] ; [expr2] ; [expr3] ) stmt1 [else stmt2] */
-static void joinstmt(lab, swp, lev, rframes) struct swtch *swp; {
-   Tree e1, e2, e3, b1, b2, b3, b4, b5, b6, b7, b8;
-   int joinid = joincounter++;
-   extern int shframedepth; 
-   int oldshframedepth;
-
-   t = gettok();  /* JOIN */
-   expect('(');
-   definept(0);
-   definelab( lab + 1 );    /* the entry point to the join statment */
-                            /* continue in the else part jumps to here */
-   b1 = tree( JBLOCKa+V, voidtype, 0, 0);
-   /* def vars ticket, gone, SM, SMsize, olddollar */
-   code(Pcode);
-   codelist->u.node = listnodes( b1, 0, 0 );
-   codelist->par = joinid;
-   walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-
-   if (kind[t] == ID) {
-      e1 = expr(';');  /* _SMSIZE */
-      code(Gen);
-      codelist->u.node = listnodes( e1, 0, 0 );
-      b2 = tree( JBLOCKb+V, voidtype, e1, 0);    /* store e1 in _SMsize */
-      code(Pcode);
-      codelist->u.node = listnodes( b2, 0, 0 );
-      codelist->par = joinid;  /*damit Sprungziel fuer verpassende Proz. */
-      walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-   }
-   else {
-      error("join requires int expression as first parameter (stacksize)");
-      expect(';');
-   }
-   
-   b3 = tree( JBLOCKc+V, voidtype, 0, 0);
-      /* save $, enter group, driver sets up SM */
-   code(Pcode);
-   codelist->u.node = listnodes( b3, 0, 0 );
-   codelist->par = joinid;     /*damit Sprungziel fuer non-Leader in JBd*/
-   walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-
-   definelab( lab+4 );
-   if (kind[t] == ID) {   /* _DELAYCOND */
-      e2 = texpr(conditional, ';');
-      walk( e2, 0, lab+4);    /* iterate until true */
-   }
-   else
-      expect(';');       /* no delay. fall through. */
-   
-   b4 = tree( JBLOCKd+V, voidtype, 0, 0);
-   code(Pcode);
-   codelist->u.node = listnodes( b4, 0, 0 );
-   codelist->par = joinid;
-   walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-       /* driver finishes sh groupframe, others 
-        * save $, build private group frame, wait for gone,
-        * and enter the bus by setting gps, eps,... to _SM
-        */
-   if (kind[t] == ID) {   /* STAYINSIDECOND */
-      e3 = texpr(conditional, ')');
-      walk( e3, lab+3, 0 );   /* jump to lab+3 (ride) if true */
-      /* ansonsten: Ausstieg und zum Else / DefaultElse springen */
-      b5 = tree( JBLOCKe+V, voidtype, 0, 0); /* leave group frame */
-      code(Pcode);
-      codelist->u.node = listnodes( b5, 0, 0 );
-      walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-      branch( lab+5 );
-   }
-   else
-      expect(')');    /* no springoffcond. fall through. */
-
-   definelab( lab+3 );
-   b6 = tree( JBLOCKf+V, voidtype, 0, 0);
-   code(Pcode);
-   codelist->u.node = listnodes( b6, 0, 0 );
-   codelist->par = joinid;
-   /* I ride: synchronize and take off */
-   walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-
-   isinsyncmode = 1; isinsideastartbody = 1;
-   oldshframedepth = shframedepth;
-   shframedepth = 0; 
-   /* BUSTOUR: */
-   statement(lab+6, 0, lev, 0, 0, rframes); /* no former frames to flush. */
-   /*        loop  swp lev   bf cf rf         */
-   definelab( lab+6 );    /* Beginn Ausstieg */
-   shframedepth = oldshframedepth;
-   isinsyncmode = 0; isinsideastartbody = 0;
-
-   b7 = tree( JBLOCKg+V, voidtype, 0, 0);
-   code(Pcode);
-   codelist->u.node = listnodes( b7, 0, 0 );
-   codelist->par = joinid;
-      /* restore ticket, gone; restore group frames, restore $ */
-   walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-
-   branch(lab + 2);    /* vom Ausstieg zum Join-Ende springen */
-
-   if (t == ELSE) {   /* optional else part */
-      t = gettok();  /*ELSE*/
-      definelab(lab+5);
-      b8 = tree( JBLOCKh+V, voidtype, 0, 0); /* restore $ */
-      code(Pcode);
-      codelist->u.node = listnodes( b8, 0, 0 );
-      codelist->par = joinid;
-      walk(0,0,0);   /*damit vorangehende stmts geflusht werden*/
-      /* busywait: */
-      statement(lab, swp, lev,       0,      0, rframes);
-      /*                         bframes  cframes           */
-      /* if ref */
-      definelab(lab);
-      /* continue springt nach lab+1, d.h. ganz an den Anfang von join */
-      /* break springt nach lab+2, d.h. ganz ans Ende von join */
-      branch( lab + 2 ); /* falls kein continue kam: nicht nochmal versuchen */
-      walk(0,0,0);
-   }
-   else {
-      /* default-Else: wird erzeugt, wenn kein else codiert ist.
-       * Hier kommt hin, wer den Bus verpasst hat 
-       * oder wer absprang und bereits aus der Busgruppe ausgestiegen ist
-       */
-      definelab(lab+5);
-      /* Springe ans Join-Ende und versuche es nicht nochmal.*/
-      branch( lab+2 );   /* d.h. else break; */
-      walk(0,0,0);
-   }
-
-   /* Join-Ende*/
-   definelab(lab + 2);
-   walk(0,0,0);
-
-}  /* joinstmt() */
-
-
 /* xxxforstmt - xxxfor ( [expr1] ; [expr2] ; [expr3] ) statement */
 static void xxxforstmt(lab, swp, lev, rframes) struct swtch *swp; {
    Tree e1, e2, e3;
@@ -476,7 +334,6 @@ static void xxxforstmt(lab, swp, lev, rframes) struct swtch *swp; {
    static char follow[] = { IF, ID, '}', 0 };
    int priv, reallypriv;     /*CWK*/
    extern void enlgrp(int), exlgrp(), synchronize(), size();
-   extern int shframedepth; 
 
    e1 = e2 = e3 = 0;
    t = gettok();
@@ -504,7 +361,6 @@ static void xxxforstmt(lab, swp, lev, rframes) struct swtch *swp; {
       test(')', follow);
    if (glevel == 2) {   /* e1; L: if (!e2) goto L+2; S; L+1: e3; goto L; L+2: */
       if (priv) enlgrp( 1 );    /*CWK*/
-      if (priv) shframedepth++;  // 990712 moved here
       definelab(lab);
       definept(&pt2);
       if (e2)
@@ -520,7 +376,6 @@ static void xxxforstmt(lab, swp, lev, rframes) struct swtch *swp; {
    } else {   /* e1; goto L+3; L: S; L+1: e3; L+3: if (e2) goto L; L+2: */
       int once = 0;
       if (priv) enlgrp( 1 );    /*CWK*/
-      if (priv) shframedepth++;   // 990712 moved here
       if (e2) {
          once = foldcond(e1, e2);
          if (!once)
@@ -546,8 +401,6 @@ static void xxxforstmt(lab, swp, lev, rframes) struct swtch *swp; {
    }
    if (findlabel(lab + 2)->ref)
       definelab(lab + 2);
-   if (priv) shframedepth--;   // 990712 nicht vorher, da e2 und e3
-                               // bei sh locals eins tiefer greifen muessen.
    if (priv) exlgrp();    /*CWK*/
    /*if (priv)*/ synchronize();   /*CWK*/
 }
@@ -558,7 +411,6 @@ static void forkstmt(lab, swp, lev, bframes, cframes, rframes) struct swtch *swp
    Coordinate pt2, pt3;
    static char follow[] = { IF, ID, '}', 0 };
    extern void mkgrp(), engrp(), exgrp(), synchronize(), ibp(int);  /* in gen.c */
-   extern int shframedepth; 
 
    e1 = e2 = e3 = 0;
    t = gettok();
@@ -567,15 +419,15 @@ static void forkstmt(lab, swp, lev, bframes, cframes, rframes) struct swtch *swp
    if (kind[t] == ID) {
       e1 = expr(';');
       if (may_dep_on_pr_var( e1 ))  /*CWK*/
-         warning("fork: number of groups must not depend on private value!\n");
+        error("fork statement: number of groups must not depend on private var!\n");
    }
    else {
-      error("fork: number of groups required!\n");
+      error("fork statement: number of groups required!\n");
       expect(';');
    }
    if (e1) {
       e1 = tree(MKGRPV, voidtype, e1, 0 );    /*CWK*/
-      code(Gen);
+      code(Gen); 
       codelist->u.node = listnodes(e1, 0, 0);
    }  /* spoolout */
    definept(0);
@@ -597,25 +449,18 @@ static void forkstmt(lab, swp, lev, bframes, cframes, rframes) struct swtch *swp
    walk(e2, 0, 0);
    definept(0);
    engrp();
-   shframedepth ++;
-   if (kind[t] == ID) {
+   if (kind[t] == ID)
       e3 = texpr(expr0, ')');
-      walk(e3, 0, 0);
-   }
-   else if (t==')') {
-      warning("fork: no expression renaming $!\n");
-      t = gettok();
-   }
    else {
-      error("fork: expression renaming $ expected!\n");
+      error("fork statement: new proc number expression for $ expected!\n");
       test(')',follow);
    }
+   walk(e3, 0, 0);
    definept(0);
    if (glevel) ibp( 6 );      /*950504*/
    /* definelab(lab);  break/continue aus der fork-Anweisung moeglich 17.9. */
    statement(lab, swp, lev, bframes + 1, cframes + 1, rframes + 1);    /*CWK*/
    exgrp();
-   shframedepth --;
    synchronize();    /* nach Ruecksprache mit Helmut Seidl */
 }
 
@@ -632,8 +477,6 @@ static void syncstmt(lab, swp, lev) struct swtch *swp; {
 static void startstmt(lab, swp, lev) struct swtch *swp; {
    Tree e;
    extern void sproc(), xproc();
-   extern int shframedepth; 
-   int oldshframedepth;
 
    t = gettok();
    if (t=='(')  {  /*Expression follows*/
@@ -661,14 +504,9 @@ static void startstmt(lab, swp, lev) struct swtch *swp; {
      code(Gen); 
      codelist->u.node = listnodes(e, 0, 0);
    }
-   isinsyncmode = 1; isinsideastartbody = 1;
-   oldshframedepth = shframedepth; /*980129*/
-   shframedepth = 0; /*vorher ++ 980129*/
-   /*testweise raus 970908 oldshoffset = shoffset; shoffset = 0;   /*970903*/
+   isinsyncmode = 1;
    statement(lab, swp, lev, 0, 0, 0);   /*CWK: no former frames to flush. */
-   shframedepth = oldshframedepth; /*980129*/
-   /* testweise raus 970908 shoffset = oldshoffset;   /*970903*/
-   isinsyncmode = 0; isinsideastartbody = 0;
+   isinsyncmode = 0;
    xproc();
 }
 
@@ -701,7 +539,6 @@ static void xxxifstmt(lab, loop, swp, lev, bframes, cframes, rframes) struct swt
    extern void nextcase();   /*CWK*/
    extern void lgrp_if();   /*CWK*/
    extern void synchronize();   /*CWK*/
-   extern int shframedepth; 
    t = gettok();
    expect('(');
    definept(0);
@@ -712,17 +549,13 @@ static void xxxifstmt(lab, loop, swp, lev, bframes, cframes, rframes) struct swt
    if (priv) splitSM();      /*CWK: freien Speicher gleichmaessig aufteilen */
    walk(e, 0, lab);
    if (priv) nextcase(0);    /*CWK: then-Gruppe aufmachen */
-   if (priv) shframedepth++;
    statement(loop, swp, lev, bframes+((priv)?1:0), cframes+((priv)?1:0), rframes + ((priv)?1:0));/*CWK*/
-   if (priv) shframedepth--;
    if (t == ELSE) {
       branch(lab + 1);    /* zum lgrp_if springen */
       t = gettok();
       definelab(lab);
       if (priv) nextcase(1); /*CWK: else-Gruppe aufmachen */
-      if (priv) shframedepth++;
       statement(loop, swp, lev, bframes+((priv)?1:0), cframes+((priv)?1:0), rframes + ((priv)?1:0));/*CWK*/
-      if (priv) shframedepth--;
       if (findlabel(lab + 1)->ref)
          definelab(lab + 1);
    } else {  /*dummy-Else, um die idle Prozessoren zu beschaeftigen: */
@@ -736,8 +569,7 @@ static void xxxifstmt(lab, loop, swp, lev, bframes, cframes, rframes) struct swt
    if (priv) synchronize();  /*CWK: synchr. im alten Frame */
 }
 
-/* localaddr - returns q if p yields the address of local/parameter q;
-   otherwise returns 0 */
+/* localaddr - returns q if p yields the address of local/parameter q; otherwise returns 0 */
 static Symbol localaddr(p) Tree p; {
    if (p == 0)
       return 0;
@@ -745,7 +577,6 @@ static Symbol localaddr(p) Tree p; {
    case INDIR: case CALL: case ARG: case RARG: case SARG:  /*CWK*/
       return 0;
    case ADDRL: case ADDRF:
-   case ADDRSL: case ADDRSF:   /*neu 970902 CWK*/
       return p->u.sym;
    case RIGHT: case ASGN:
       if (p->kids[1])
@@ -823,9 +654,9 @@ void retcode(p, lab, rframes) Tree p; {
    }
    assert( rframes >= 0 );   /*CWK*/
    p->rframes = rframes;     /*CWK*/
-   p->started = isinsideastartbody; /*!(cfunc->sync) && isinsyncmode;     /*CWK*/
+   p->started = !(cfunc->sync) && isinsyncmode;     /*CWK*/
    if (isinsyncmode && cfunc && !(cfunc->sync))              /*CWK*/
-      warning("return crossing start/join boundary may destroy synchronity\n"); 
+      warning("return crossing start/join boundary will destroy synchronity\n"); 
    walk(p, 0, 0);
    branch(lab);
 }
@@ -911,29 +742,6 @@ void statement(loop, swp, lev, bframes, cframes, rframes) struct swtch *swp; {
       expect(':');
       statement(loop, swp, lev, bframes, cframes, rframes);
       break;
-   case SEQ: {                        /*970310 CWK*/
-      extern void begseq(int), endseq(int);
-      int mylabelnr = SEQcounter++;
-      int ignore = 0;
-      if (!isFORKmodul) {
-         ignore = 1;
-         error("seq is a FORK-specific statement!\n");
-      }
-      if (!isinsyncmode) {
-         ignore = 1;
-         warning("seq in asynchronous context is ignored\n");
-      }
-      t = gettok();
-      isinsyncmode = 0;
-      walk(0,0,0);   /*damit vorangehende stmts geflusht werden 970612*/
-      if (!ignore)  begseq( mylabelnr );
-      statement(loop, swp, lev, bframes, cframes, rframes );
-      if (! ignore) {
-         endseq( mylabelnr );
-         isinsyncmode = 1;
-      }
-      break;
-      }
    case FARM: {                                                       /*CWK*/
       extern void ibp( int );
       int ignore = 0;
@@ -956,32 +764,19 @@ void statement(loop, swp, lev, bframes, cframes, rframes) struct swtch *swp; {
       }
       break;
       }
-   case JOIN:           /*990126*/
-      if (isFORKmodul)
-        if (!isinsyncmode)
-          joinstmt(genlabel(7), swp, lev+1, rframes);   /*CWK*/
-        else
-          error("join only permitted in asynchronous mode");
-      else
-        error("join is a Fork95-specific statement, compile with -FORK");
-      break;
    case BEGINSYNC:        /* 950912 */
       if (isinsyncmode)
          error("beginsync statement is not allowed in synchronous context\n");
       t = gettok();
-      isinsyncmode = 1; isinsideastartbody = 1;
+      isinsyncmode = 1;
       statement(loop, swp, lev, 0, 0, 0);
-      isinsyncmode = 0; isinsideastartbody = 0;
+      isinsyncmode = 0;
       break;
    case RETURN:
       t = gettok();
       definept(0);
       if (cfunc->sync && !isinsyncmode)
          error("return from inside a farm statement is forbidden!\n");
-      if (!isinsyncmode && isinsideastartbody)  /*970821*/
-         warning("return crossing start/join and farm/seq boundary may destroy synchronity\n"); 
-      if (rframes)  /* 990527 count only "harmful" returns */
-         cfunc->nreturns ++;  /* 990525 */
       if (t != ';')
          if (freturn(cfunc->type) == voidtype) {
             error("extraneous return value\n");
@@ -1207,8 +1002,6 @@ static void swstmt(loop, lab, lev, bframes, cframes, rframes) {  /*CWK*/
       error("illegal type `%t' in switch expression\n", e->type);
       e = retype(e, inttype);
    }
-   if (isinsyncmode && may_dep_on_pr_var( e ))  /*CWK 961112*/
-      warning("private switch selector in synchronous mode will probably cause deadlock!\n");
    e = cast(e, promote(e->type));
    if (generic(e->op) == INDIR && isaddrop(e->kids[0]->op)
    && e->kids[0]->u.sym->type == e->type && !isvolatile(e->kids[0]->u.sym->type)) {
@@ -1294,7 +1087,6 @@ static void xxxwhilestmt(lab, swp, lev, rframes) struct swtch *swp; {
    Tree e;
    int priv;        /*CWK*/
    extern void enlgrp(int), exlgrp(), size(), synchronize();
-   extern int shframedepth; 
 
    refinc *= 10;
    t = gettok();
@@ -1304,22 +1096,16 @@ static void xxxwhilestmt(lab, swp, lev, rframes) struct swtch *swp; {
    e = texpr(conditional, ')');
    priv = (may_dep_on_pr_var( e )); /*CWK*/
    priv = 1;   /*CWK: wegen break notwendig!*/
-   if (generic(e->op) == CNST /* || glevel == 2*/ ) {   /*CWK: CNST = shared!*/
-                              // ^^^^ this makes only trouble. 990712
+   if (generic(e->op) == CNST || glevel == 2) {   /*CWK: CNST = shared!*/
          /* L, L+1: if (!e) goto L+2; S; goto L; L+2: */
       definelab(lab);
       definelab(lab + 1);
       definept(&pt);
       walk(e, 0, lab + 2);
-      //if (priv) shframedepth++;   // raus 990712
-      statement(lab, swp, lev, 0, 0, rframes ); // raus + ((priv)?1:0)); /*CWK*/
-      //if (priv) shframedepth--;   // raus 990712
+      statement(lab, swp, lev, 0, 0, rframes + ((priv)?1:0)); /*CWK*/
       branch(lab);
-      if (findlabel(lab + 2)->ref)
-         definelab(lab + 2);
    } else {   /* goto L+1; L: S; L+1: if (E) goto L; L+2: */
       if (priv) enlgrp( 0 );    /*CWK*/
-      if (priv) shframedepth++;
       branch(lab + 1);
       definelab(lab);
       if (priv) size();     /*CWK*/
@@ -1327,13 +1113,11 @@ static void xxxwhilestmt(lab, swp, lev, rframes) struct swtch *swp; {
       definelab(lab + 1);
       definept(&pt);
       walk(e, lab, 0);
-      if (priv) shframedepth--;  // 990712 moved across eval(e)
-      if (findlabel(lab + 2)->ref)
-         definelab(lab + 2);
-      if (priv) exlgrp();    /*CWK*/ // 990712 moved upwards:
-                                     // close frame only if opened
    }
+   if (findlabel(lab + 2)->ref)
+      definelab(lab + 2);
    /* keine Nops, weil am Ende synchronisiert wird.  CWK*/
+   if (priv) exlgrp();    /*CWK*/
    synchronize();
    /*CWK, es muss auch bei shared Bedingung immer synchronisiert werden*/
 }
