@@ -124,10 +124,8 @@ zz(SYNCF,      99,   0,   0,   0,   SHARED,   "sync")
 zz(ASYNCF,     100,   0,   0,   0,   SHARED,   "async")
 /* vormals yy(0,      100,   0,   0,   0,   0,   0) CWK */
 zz(BEGINSYNC,   101,   0,   0,   0,   IF,   "beginsync")
-zz(JOIN,       102,   0,   0,   0,   IF,   "join")  /*961024*/
-/* vormals yy(0,      102,   0,   0,   0,   0,   0) CWK */
-zz(SEQ,       103,   0,   0,   0,   IF,   "seq")  /*970310*/
-/* vormals yy(0,      103,   0,   0,   0,   0,   0) CWK*/
+yy(0,      102,   0,   0,   0,   0,   0)
+yy(0,      103,   0,   0,   0,   0,   0)
 yy(0,      104,   0,   0,   0,   0,   0)
 yy(0,      105,   0,   0,   0,   0,   0)
 yy(0,      106,   0,   0,   0,   0,   0)
